@@ -482,8 +482,7 @@ client_set_restart_command (GnomeClient *client)
   vals[i].length = strlen (sm_screen);
   vals[i++].value = (char *)sm_screen;
   vals[i].length = strlen (tmp);
-  vals[i++].value = g_strdup(tmp);
-  g_free(tmp);
+  vals[i++].value = tmp;
 #endif
 
   for (list = client->static_args; list; list = g_list_next (list))
@@ -501,6 +500,10 @@ client_set_restart_command (GnomeClient *client)
   client_set_value (client, SmRestartCommand, SmLISTofARRAY8, i, vals);
 
   g_free (vals);
+
+#ifdef HAVE_GTK_MULTIHEAD
+  g_free (tmp);
+#endif
 }
 
 static void
@@ -980,6 +983,8 @@ gnome_client_module_info_get (void)
 	if (module_info.requirements == NULL) {
 		static GnomeModuleRequirement req[3];
 
+		bindtextdomain (GETTEXT_PACKAGE, GNOMEUILOCALEDIR);
+
 		req[0].required_version = "1.3.7";
 		req[0].module_info = gnome_gtk_module_info_get ();
 
